@@ -3,8 +3,8 @@ package Class::MOP::Method;
 BEGIN {
   $Class::MOP::Method::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $Class::MOP::Method::VERSION = '2.0205';
+{
+  $Class::MOP::Method::VERSION = '2.0400';
 }
 
 use strict;
@@ -153,7 +153,7 @@ Class::MOP::Method - Method Meta Object
 
 =head1 VERSION
 
-version 2.0205
+version 2.0400
 
 =head1 DESCRIPTION
 
@@ -254,6 +254,12 @@ If this method is a clone of a clone (of a clone, etc.), this method
 returns the fully qualified name from the I<first> method in the chain
 of clones.
 
+=item B<< $metamethod->is_stub >>
+
+Returns true if the method is just a stub:
+
+  sub foo;
+
 =item B<< $metamethod->attach_to_class($metaclass) >>
 
 Given a L<Class::MOP::Class> object, this method sets the associated
@@ -281,7 +287,7 @@ metaclass.
 
 =head1 AUTHOR
 
-Stevan Little <stevan@iinteractive.com>
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
