@@ -2,22 +2,24 @@ package Class::MOP::MiniTrait;
 BEGIN {
   $Class::MOP::MiniTrait::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $Class::MOP::MiniTrait::VERSION = '2.0205';
+{
+  $Class::MOP::MiniTrait::VERSION = '2.0400';
 }
 
 use strict;
 use warnings;
 
+use Class::Load qw(load_class);
+
 sub apply {
     my ( $to_class, $trait ) = @_;
 
     for ( grep { !ref } $to_class, $trait ) {
-        Class::MOP::load_class($_);
+        load_class($_);
         $_ = Class::MOP::Class->initialize($_);
     }
 
-    for my $meth ( $trait->get_all_methods ) {
+    for my $meth ( grep { $_->package_name ne 'UNIVERSAL' } $trait->get_all_methods ) {
         my $meth_name = $meth->name;
 
         if ( $to_class->find_method_by_name($meth_name) ) {
@@ -37,19 +39,40 @@ require Class::MOP;
 
 1;
 
-__END__
+# ABSTRACT: Extremely limited trait application
+
+
 
 =pod
 
-=head1 NAME 
+=head1 NAME
 
 Class::MOP::MiniTrait - Extremely limited trait application
 
+=head1 VERSION
+
+version 2.0400
+
 =head1 DESCRIPTION
 
 This package provides a single function, C<apply>, which does a half-assed job
 of applying a trait to a class. It exists solely for use inside Class::MOP and
 L<Moose> core classes.
 
+=head1 AUTHOR
+
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
+
+__END__
+
+
