@@ -2,8 +2,8 @@ package Moose::Error::Confess;
 BEGIN {
   $Moose::Error::Confess::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $Moose::Error::Confess::VERSION = '2.0205';
+{
+  $Moose::Error::Confess::VERSION = '2.0400';
 }
 
 use strict;
@@ -40,7 +40,7 @@ Moose::Error::Confess - Prefer C<confess>
 
 =head1 VERSION
 
-version 2.0205
+version 2.0400
 
 =head1 SYNOPSIS
 
@@ -59,7 +59,7 @@ metaclass.
 
 =head1 AUTHOR
 
-Stevan Little <stevan@iinteractive.com>
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
