@@ -2,8 +2,8 @@ package Moose::Error::Croak;
 BEGIN {
   $Moose::Error::Croak::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $Moose::Error::Croak::VERSION = '2.0205';
+{
+  $Moose::Error::Croak::VERSION = '2.0400';
 }
 
 use strict;
@@ -40,7 +40,7 @@ Moose::Error::Croak - Prefer C<croak>
 
 =head1 VERSION
 
-version 2.0205
+version 2.0400
 
 =head1 SYNOPSIS
 
@@ -69,7 +69,7 @@ Overrides L<Moose::Error::Default/new> to prefer C<croak>.
 
 =head1 AUTHOR
 
-Stevan Little <stevan@iinteractive.com>
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
