@@ -2,8 +2,8 @@ package Moose::Error::Default;
 BEGIN {
   $Moose::Error::Default::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $Moose::Error::Default::VERSION = '2.0205';
+{
+  $Moose::Error::Default::VERSION = '2.0400';
 }
 
 use strict;
@@ -65,7 +65,7 @@ Moose::Error::Default - L<Carp> based error generation for Moose.
 
 =head1 VERSION
 
-version 2.0205
+version 2.0400
 
 =head1 DESCRIPTION
 
@@ -96,7 +96,7 @@ Creates a new errors string of the specified style.
 
 =head1 AUTHOR
 
-Stevan Little <stevan@iinteractive.com>
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
