@@ -2,14 +2,15 @@ package Moose::Meta::Role::Composite;
 BEGIN {
   $Moose::Meta::Role::Composite::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $Moose::Meta::Role::Composite::VERSION = '2.0205';
+{
+  $Moose::Meta::Role::Composite::VERSION = '2.0400';
 }
 
 use strict;
 use warnings;
 use metaclass;
 
+use Class::Load qw(load_class);
 use Scalar::Util 'blessed';
 
 use base 'Moose::Meta::Role';
@@ -126,7 +127,7 @@ sub get_method {
 
 sub apply_params {
     my ($self, $role_params) = @_;
-    Class::MOP::load_class($self->application_role_summation_class);
+    load_class($self->application_role_summation_class);
 
     $self->application_role_summation_class->new(
         role_params => $role_params,
@@ -165,7 +166,7 @@ Moose::Meta::Role::Composite - An object to represent the set of roles
 
 =head1 VERSION
 
-version 2.0205
+version 2.0400
 
 =head1 DESCRIPTION
 
@@ -220,7 +221,7 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little <stevan@iinteractive.com>
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
