@@ -3,8 +3,8 @@ package Moose::Meta::Role::Method::Required;
 BEGIN {
   $Moose::Meta::Role::Method::Required::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $Moose::Meta::Role::Method::Required::VERSION = '2.0205';
+{
+  $Moose::Meta::Role::Method::Required::VERSION = '2.0400';
 }
 
 use strict;
@@ -41,7 +41,7 @@ Moose::Meta::Role::Method::Required - A Moose metaclass for required methods in
 
 =head1 VERSION
 
-version 2.0205
+version 2.0400
 
 =head1 DESCRIPTION
 
@@ -79,7 +79,7 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little <stevan@iinteractive.com>
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
