@@ -2,8 +2,8 @@ package Moose::Util::MetaRole;
 BEGIN {
   $Moose::Util::MetaRole::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $Moose::Util::MetaRole::VERSION = '2.0205';
+{
+  $Moose::Util::MetaRole::VERSION = '2.0400';
 }
 
 use strict;
@@ -152,7 +152,7 @@ Moose::Util::MetaRole - Apply roles to any metaclass, as well as the object base
 
 =head1 VERSION
 
-version 2.0205
+version 2.0400
 
 =head1 SYNOPSIS
 
@@ -299,7 +299,7 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little <stevan@iinteractive.com>
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
